@@ -19,15 +19,14 @@
 
 package org.apache.drill.exec.expr.fn.impl;
 
-import static org.apache.drill.shaded.guava.com.google.common.base.Preconditions.checkArgument;
-import static org.apache.drill.shaded.guava.com.google.common.base.Preconditions.checkState;
+import static com.google.common.base.Preconditions.checkArgument;
+import static com.google.common.base.Preconditions.checkState;
 
-import org.apache.drill.shaded.guava.com.google.common.collect.Lists;
-import org.apache.drill.shaded.guava.com.google.common.collect.ObjectArrays;
-import org.apache.drill.shaded.guava.com.google.common.base.Charsets;
-import org.apache.drill.shaded.guava.com.google.common.collect.ObjectArrays;
+import com.google.common.collect.Lists;
+import com.google.common.collect.ObjectArrays;
+import com.google.common.collect.ObjectArrays;
 
-import org.apache.drill.shaded.guava.com.google.common.base.Preconditions;
+import com.google.common.base.Preconditions;
 import io.netty.buffer.*;
 
 import org.apache.commons.lang3.ArrayUtils;
@@ -71,6 +70,7 @@ import java.io.Closeable;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.nio.ByteBuffer;
+import java.nio.charset.StandardCharsets;
 
 import java.sql.Date;
 import java.sql.Time;
